pub struct ABTestReport {
pub control_name: String,
pub treatment_name: String,
pub control_stats: VariantStats,
pub treatment_stats: VariantStats,
pub ttest: TTestResult,
pub mann_whitney: MannWhitneyResult,
pub cohens_d: f64,
pub significant: bool,
pub winner: Winner,
pub significance_level: f64,
}Expand description
Full A/B test analysis report.
Fields
control_name: Stringtreatment_name: Stringcontrol_stats: VariantStatstreatment_stats: VariantStatsttest: TTestResultmann_whitney: MannWhitneyResultcohens_d: f64Cohen’s d effect size.
significant: boolTrue iff both tests are below significance_level.
winner: Winnersignificance_level: f64Implementations
Sourceimpl ABTestReport
impl ABTestReport
Sourcepub fn treatment_wins(&self) -> bool
pub fn treatment_wins(&self) -> bool
Return true if the treatment is the statistically significant winner.
Sourcepub fn control_wins(&self) -> bool
pub fn control_wins(&self) -> bool
Return true if the control is the statistically significant winner.
Sourcepub fn relative_improvement(&self) -> f64
pub fn relative_improvement(&self) -> f64
Relative improvement of treatment over control: (trt - ctrl) / |ctrl|.