pub struct CrossLingualAligner { /* private fields */ }Expand description
Aligns multiple language embedding spaces via a pivot language.
Implementations
Sourceimpl CrossLingualAligner
impl CrossLingualAligner
Sourcepub fn add_language(&mut self, lang: &str, embeddings: Vec<Vec<f32>>)
pub fn add_language(&mut self, lang: &str, embeddings: Vec<Vec<f32>>)
Register an embedding space for a language.
Sourcepub fn align_to_pivot(
&self,
lang: &str,
seed_pairs: &[AlignmentPair],
) -> Option<AlignmentResult>
pub fn align_to_pivot( &self, lang: &str, seed_pairs: &[AlignmentPair], ) -> Option<AlignmentResult>
Align the given language to the pivot using seed pairs.
Sourcepub fn translate(
&self,
embedding: &[f32],
from_lang: &str,
to_lang: &str,
) -> Option<Vec<f32>>
pub fn translate( &self, embedding: &[f32], from_lang: &str, to_lang: &str, ) -> Option<Vec<f32>>
Translate an embedding from one language space to another via the pivot.
Sourcepub fn pivot_language(&self) -> &str
pub fn pivot_language(&self) -> &str
Pivot language accessor.