pub struct FineTuner { /* private fields */ }Expand description
Embedding fine-tuner using contrastive learning losses.
Implementations
Sourceimpl FineTuner
impl FineTuner
Sourcepub fn new(config: FinetuneConfig) -> Self
pub fn new(config: FinetuneConfig) -> Self
Create a fine-tuner with the given configuration.
Sourcepub fn compute_triplet_loss(
&self,
anchor: &[f32],
positive: &[f32],
negative: &[f32],
) -> f32
pub fn compute_triplet_loss( &self, anchor: &[f32], positive: &[f32], negative: &[f32], ) -> f32
Compute triplet margin loss.
loss = max(0, d(a,p) - d(a,n) + margin)
Sourcepub fn compute_contrastive_loss(&self, a: &[f32], b: &[f32], label: f32) -> f32
pub fn compute_contrastive_loss(&self, a: &[f32], b: &[f32], label: f32) -> f32
Compute contrastive loss for a pair.
label = 1.0(similar): loss = d²label = 0.0(dissimilar): loss = max(0, margin − d)²
Sourcepub fn compute_cosine_loss(&self, a: &[f32], b: &[f32], target: f32) -> f32
pub fn compute_cosine_loss(&self, a: &[f32], b: &[f32], target: f32) -> f32
Compute cosine similarity loss: MSE between cosine_sim(a,b) and target.
Sourcepub fn step(&mut self, pairs: &[EmbeddingPair]) -> f32
pub fn step(&mut self, pairs: &[EmbeddingPair]) -> f32
Simulate one gradient step over the given pairs and return the mean loss.
Sourcepub fn train(&mut self, pairs: &[EmbeddingPair]) -> Vec<f32>
pub fn train(&mut self, pairs: &[EmbeddingPair]) -> Vec<f32>
Run full training for config.epochs epochs and return the mean loss per epoch.
Sourcepub fn training_history(&self) -> &[TrainingStep]
pub fn training_history(&self) -> &[TrainingStep]
Access the full training history.
Sourcepub fn total_steps(&self) -> usize
pub fn total_steps(&self) -> usize
Total number of gradient steps recorded.