pub struct RotatEPlus {
pub entity_phase: Vec<Vec<f32>>,
pub relation_phase: Vec<Vec<f32>>,
pub dim: usize,
}Expand description
RotatE+ with phase-space operations.
Entities and relations are represented as phase vectors in [0, 2π). The scoring function computes the L1 distance in phase space after applying the relational rotation: score = -||h ∘ r - t||_1.
Fields
entity_phase: Vec<Vec<f32>>Entity phase embeddings: [num_entities][dim], values in [0, 2π)
relation_phase: Vec<Vec<f32>>Relation phase embeddings: [num_relations][dim], values in [0, 2π)
dim: usizeEmbedding dimension
Implementations
Sourceimpl RotatEPlus
impl RotatEPlus
Sourcepub fn new(num_entities: usize, num_relations: usize, dim: usize) -> Self
pub fn new(num_entities: usize, num_relations: usize, dim: usize) -> Self
Create a new RotatE+ model with random phase initialization.
Sourcepub fn score(&self, head: usize, relation: usize, tail: usize) -> f32
pub fn score(&self, head: usize, relation: usize, tail: usize) -> f32
Compute score = -||h ∘ r - t||_1 where ∘ is element-wise phase addition mod 2π.
Sourcepub fn update(
&mut self,
head: usize,
relation: usize,
tail: usize,
pos_score: f32,
neg_score: f32,
lr: f32,
)
pub fn update( &mut self, head: usize, relation: usize, tail: usize, pos_score: f32, neg_score: f32, lr: f32, )
Update embeddings via margin-based gradient step.
pos_score and neg_score are output from score().
We push pos_score higher and neg_score lower.
Sourcepub fn entity_count(&self) -> usize
pub fn entity_count(&self) -> usize
Number of entities
Sourcepub fn relation_count(&self) -> usize
pub fn relation_count(&self) -> usize
Number of relations