pub enum PersistenceError {
UnsupportedFormat(String),
NotImplemented(String),
Io(Error),
Serialization(String),
}Expand description
Errors specific to model persistence operations
Variants
UnsupportedFormat(String)
The requested export format requires an optional feature flag that is not enabled
NotImplemented(String)
The feature is gated behind a Cargo feature flag and not yet fully implemented
Io(Error)
IO error during persistence
Serialization(String)
Serialisation / deserialisation error