Embedding Alignment: Aligning embeddings across different knowledge graph spaces.
Supports:
- Orthogonal Procrustes (SVD-based rotation)
- Linear Transformation (general affine mapping)
- Bidirectional Matching (mutual nearest neighbor)
- Cross-lingual alignment via pivot language
Structs
- Alignment
Pair - A seed pair linking a source entity index to a target entity index.
- Alignment
Result - Result of an alignment operation.
- Cross
Lingual Aligner - Aligns multiple language embedding spaces via a pivot language.
- Embedding
Alignment - Aligns embeddings from two different KG spaces.
Enums
- Alignment
Method - Available alignment strategies.
- Alignment
Transform - Transformation applied to source embeddings to align them to target space.