pub struct EmbeddingStore { /* private fields */ }Expand description
In-memory store for labelled embedding vectors.
Implementations
Sourceimpl EmbeddingStore
impl EmbeddingStore
Sourcepub fn insert(
&mut self,
label: impl Into<String>,
vector: Vec<f64>,
) -> Result<usize, StoreError>
pub fn insert( &mut self, label: impl Into<String>, vector: Vec<f64>, ) -> Result<usize, StoreError>
Insert a new embedding.
All vectors in the store must have the same dimension. The first insertion fixes the dimension for all subsequent insertions.
Returns the assigned id on success.
Sourcepub fn insert_with_meta(
&mut self,
label: impl Into<String>,
vector: Vec<f64>,
meta: HashMap<String, String>,
) -> Result<usize, StoreError>
pub fn insert_with_meta( &mut self, label: impl Into<String>, vector: Vec<f64>, meta: HashMap<String, String>, ) -> Result<usize, StoreError>
Insert a new embedding with accompanying metadata.
Sourcepub fn get_by_label(&self, label: &str) -> Option<&EmbeddingEntry>
pub fn get_by_label(&self, label: &str) -> Option<&EmbeddingEntry>
Look up an entry by its label.
Sourcepub fn get_by_id(&self, id: usize) -> Option<&EmbeddingEntry>
pub fn get_by_id(&self, id: usize) -> Option<&EmbeddingEntry>
Look up an entry by its sequential id.
Sourcepub fn cosine_similarity(a: &[f64], b: &[f64]) -> f64
pub fn cosine_similarity(a: &[f64], b: &[f64]) -> f64
Compute the cosine similarity between two slices of equal length.
Returns 0.0 when either vector has zero norm.
Sourcepub fn nearest(
&self,
query: &[f64],
k: usize,
) -> Result<Vec<(&EmbeddingEntry, f64)>, StoreError>
pub fn nearest( &self, query: &[f64], k: usize, ) -> Result<Vec<(&EmbeddingEntry, f64)>, StoreError>
Return the k nearest entries to query by cosine similarity, in
descending order of similarity.
Returns StoreError::EmptyStore when the store is empty and
StoreError::DimensionMismatch when query has the wrong length.